pilas.actores.ovni

Package pilas :: Package actores :: Module ovni |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.actores.ovni

     1  # -*- encoding: utf-8 -*-
     2  # Pilas engine - A video game framework.
     3  #
     4  # Copyright 2010 - Hugo Ruscitti
     5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # Website - http://www.pilas-engine.com.ar
     8
     9  from pilas.actores import Actor
    10  import pilas
    11
    12 -class Ovni(Actor):
    13      """Representa Ovni que explota al momento de ser eliminado.
    14
    15          .. image:: images/actores/ovni.png
    16
    17      """
    18
    19 -    def __init__(self, x=0, y=0):
    20          """Constructor de la Ovni
    21
    22          :param x: Posición horizontal del ovni.
    23          :type x: int
    24          :param y: Posición vertical del ovni.
    25          :type y: int
    26
    27          """
    28          imagen = pilas.imagenes.cargar("ovni.png")
    29          Actor.__init__(self, imagen, x=x, y=y)
    30
    31          self.radio_de_colision = 20
    32
    33          self.aprender(pilas.habilidades.PuedeExplotar)
    34
    35 -    def actualizar(self):
    36          pass
    37
    38
    39 -class Planeta(Actor):
    40      """Representa un planeta para utilizar con el ovni.
    41
    42          .. image:: images/actores/planeta_azul.png
    43
    44      """
    45
    46 -    def __init__(self, x=0, y=0, color='azul'):
    47          """Constructor del planeta.
    48
    49          :param x: Posición horizontal del planeta.
    50          :type x: int
    51          :param y: Posición vertical del planeta.
    52          :type y: int
    53          :param color: El color del planeta
    54          :type color: Puede ser ``azul``, ``marron``, ``naranja``, ``rojo`` o ``verde``
    55          """
    56
    57          imagen = pilas.imagenes.cargar("planeta_{}.png".format(color))
    58          Actor.__init__(self, imagen, x=x, y=y)
    59
    60
    61 -    def actualizar(self):
    62          pass
    63